from distutils.core import setup
setup(

  name = 'nextgentermux',
  packages = ['nextgentermux'],
  #scripts=['nextxgentermux/nextgen']
  version = '1.3',
  license='gpl-3.0', 
  description = 'An one tap termux setup tool',
  url = 'https://github.com/Ign0r3dH4x0r/NextGenTermux',
  download_url = 'https://github.com/smsowmik/NextGenTermux/archive/1.1.tar.gz',
  classifiers=[
    'Development Status :: 5 - Production/Stable',    
    'Intended Audience :: Developers', 
    'Topic :: Adaptive Technologies',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Programming Language :: Unix Shell',  
  ],


)
